##  Lifecycle and Cross-Project Referencing of Milestones
Milestones can be referenced in the Lifecycle section of Initiative Fact Sheets, either within the same Fact Sheet or in other Fact Sheets. It's important to note that milestones are only available to other Fact Sheets along the parent-child hierarchy.
The milestone date is automatically reflected wherever it has been referenced. Any changes made to a milestone in the parent Fact Sheet are automatically reflected in all instances, simplifying the management and monitoring of dependencies between Initiatives.
To reference a Milestone, follow the below instructions:
  1. In the Initiative Fact Sheet, click on the Edit button located at the top right corner of the Lifecycle section.
  2. Click on the Milestone icon (Diamond shape), next to the Lifecycle fields, to switch from absolute date to milestones.
  3. Select the required Milestone from the drop-down menu in the field.
![Referencing Milestones in Lifecycle fields](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274190b37a4410148a60fd54b98f4ba1_LowRes.png)
Referencing Milestones in Lifecycle fields
